==> tencentcloud-sdk-java-3.0.93-sources.jar: com/tencentcloudapi/tci/v20190318/models/DoubleVideoFunction.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.tci.v20190318.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DoubleVideoFunction  extends AbstractModel{

    /**
    * 片头片尾增加图片开关
    */
    @SerializedName("EnableCoverPictures")
    @Expose
    private Boolean EnableCoverPictures;

    /**
     * 获取片头片尾增加图片开关
     * @return EnableCoverPictures 片头片尾增加图片开关
     */
    public Boolean getEnableCoverPictures() {
        return this.EnableCoverPictures;
    }

    /**
     * 设置片头片尾增加图片开关
     * @param EnableCoverPictures 片头片尾增加图片开关
     */
    public void setEnableCoverPictures(Boolean EnableCoverPictures) {
        this.EnableCoverPictures = EnableCoverPictures;
    }

    /**
     * 内部实现，用户禁止调用
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "EnableCoverPictures", this.EnableCoverPictures);

    }
}

==> tencentcloud-sdk-java-3.1.62-sources.jar: com/tencentcloudapi/tci/v20190318/models/DoubleVideoFunction.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.tci.v20190318.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DoubleVideoFunction extends AbstractModel{

    /**
    * 片头片尾增加图片开关
    */
    @SerializedName("EnableCoverPictures")
    @Expose
    private Boolean EnableCoverPictures;

    /**
     * Get 片头片尾增加图片开关 
     * @return EnableCoverPictures 片头片尾增加图片开关
     */
    public Boolean getEnableCoverPictures() {
        return this.EnableCoverPictures;
    }

    /**
     * Set 片头片尾增加图片开关
     * @param EnableCoverPictures 片头片尾增加图片开关
     */
    public void setEnableCoverPictures(Boolean EnableCoverPictures) {
        this.EnableCoverPictures = EnableCoverPictures;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "EnableCoverPictures", this.EnableCoverPictures);

    }
}
